@@ -26,11 +26,11 @@ Lavoco::Web::Editor - Experimental framework with two constraints: FastCGI and T
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 $VERSION = eval $VERSION;
 
@@ -108,7 +108,7 @@ Number of FastCGI process to spawn, 5 by default.
 
 =head3 filename
 
-Filename for the config file, default is C<app.json> and only JSON is currently supported.
+Filename for the config file, default is C<editor.json> and only JSON is currently supported.
 
 =head3 config
 
@@ -324,19 +324,25 @@ The config file should be placed in the C<base> directory of your editor applica
 See the C<examples> directory for a sample JSON config file, something like the following...
 
  {
-   
-    ...
+     "password" : "foo",
+     "salt"     : "abc123",
+     "folders"  : [
+         "templates/content/organic",
+         "templates/content/store"
+     ],
+     "files"    : [
+         "app.json",
+         "site/style.css"
+     ]
  }
 
-The entire config hash is available in all templates via C<[% app.config %]>.
-
 Two fields which drive the editor are C<folders> and C<files>, each of which is an array of paths, all relative to C<$editor-E<gt>base>.
 
-When a folder is found, all files within it are editable, but not the sub directories.  You are also able to create new files in this folder.
+Files in the folders are all editable, but not sub-directories, you need to add those separately.
 
 If the field for C<password> exists in the config, then this will be requested before a user can access the index page (listing all files that can be edited).
 
-When using a C<password>, a C<slat> is also required, just create a random string that gets concatenated to the password before SHA-hashing and setting as a cookie.
+When using a C<password>, a C<salt> is also required, just create a random string, it's concatenated to the password before SHA-hashing and setting as a cookie.
 
 =cut
 
@@ -715,6 +721,8 @@ EOF
 
 =head1 TODO
 
+Allow absolute paths to any part of the filesystem?
+
 =head1 AUTHOR
 
 Rob Brown, C<< <rob at intelcompute.com> >>
